#ifndef LQMEAS_LTR11_H
#define LQMEAS_LTR11_H


#include "ltr/include/ltr11api.h"
#include "lqmeas/devs/LTR/modules/LTRModule.h"
#include "lqmeas/ifaces/in/adc/DevAdc.h"
#include <QScopedPointer>


namespace LQMeas {
    class LTR11Config;
    class LTR11Info;
    class LTRModuleFrameReceiver;

    class LTR11 : public LTRModule, public DevAdc {
        Q_OBJECT
    public:
        static const quint16 typeModuleID {LTR_MID_LTR11};
        ~LTR11() override;

        bool isOpened() const override;
        /* ----------------------- интерфейс ввода  --------------------------*/
        DevAdc *devAdc() override {return static_cast<DevAdc*>(this);}
        DevSyncMarksRecv *devSyncMarkRecv() override;

        QString errorString(int err) const override;

        bool adcIsRunning() const override {return m_run;}

        const LTR11Config &devspecConfig() const;
        const LTR11Info &devspecInfo() const;
    protected:
        TLTR* channel() const override;

        void protOpen(OpenFlags flags, LQError &err) override;
        void protClose(LQError &err) override;
        void protConfigure(const DeviceConfig &cfg, LQError &err) override;

        INT ltrRawWordsReceive(DWORD *wrds, DWORD *marks, DWORD size, DWORD tout) override;

        void protAdcStart(LQError &err) override;
        void protAdcStop(LQError &err) override;
        void protAdcGetData(double *data, int size, unsigned flags,
                            unsigned tout, int &recvd_size, LQError &err) override;
    private:
        explicit LTR11(LTRCrate *crate, int slot, QObject *parent = nullptr);
        mutable TLTR11 m_hnd;
        QScopedPointer<LTRModuleFrameReceiver> m_receiver;
        bool m_run {false};

        friend class LTRResolver;
    };
}

#endif // LQMEAS_LTR11_H
