#ifndef LQMEAS_LTR114ADCCONFIG_H
#define LQMEAS_LTR114ADCCONFIG_H

#include "lqmeas/ifaces/in/adc/DevAdcSeqBaseConfig.h"
#include "ltr/include/ltr114api.h"

namespace LQMeas {
    class LTR114AdcConfig : public DevAdcSeqBaseConfig {
        Q_OBJECT
    public:
        static const int adc_channels_cnt {16};
        static const int adc_diff_channels_cnt {16};
        static const int adc_r_channels_cnt {8};

        enum class AdcChRange {
            U_10 = 0,
            U_2 = 1,
            U_0_4 = 2,

            R_4000 = 0,
            R_1200 = 1,
            R_400 = 2,
        };


        enum class AdcChMode {
            Diff,
            R,
            AlternatingR
        };


        enum class SyncMode {
            Internal,
            Master,
            ExternalSlave
        };

        enum class AutoCbrMode {
            OnStart,
            OnOperation
        };




        int adcUnitMode(int ch) const override;

        int adcChRangeNum(int ch) const override {return m_ch_params[ch].Range;}
        AdcChRange adcChRange(int ch) const {return static_cast<AdcChRange>(adcChRangeNum(ch));}
        AdcChMode adcChMode(int ch) const {return m_ch_params[ch].Mode;}


        bool adcExternalStart() const override {
            return m_syncMode != SyncMode::ExternalSlave;
        }

        SyncMode  syncMode() const {return m_syncMode;}
        AutoCbrMode autoCbrMode() const {return m_autoCbrMode;}

        static int typeAdcRangeNum(AdcChRange range) {return static_cast<int>(range);}
    Q_SIGNALS:
        void syncModeChanged();
        void adcChModeChanged(int ch);
        void adcAutoCbrModeChanged();
    public Q_SLOTS:
        void setSyncMode(SyncMode mode);
        void setAutoCbrMode(AutoCbrMode cbrMode);
        void adcSetChMode(int ch, AdcChMode mode);
        void adcSetChRangeNum(int ch, int range_num);
        void adcSetChRange(int ch, AdcChRange range) {
            adcSetChRangeNum(ch, typeAdcRangeNum(range));
        }
    protected:
        void protSave(QJsonObject &cfgObj) const override;
        void protLoad(const QJsonObject &cfgObj) override;

        void adcChSave(int ch, QJsonObject &chObj) const override;
        void adcChLoad(int ch, const QJsonObject &chObj) override;
        void adcChSetDefault(int ch) override;
        void adcAdjustFreq(double *adcFreq, double *adcChFreq) override;
    private:
        static INT adcChRangeCodeU(int range_num);
        static INT adcChRangeCodeR(int range_num);

        LTR114AdcConfig(const DevAdcInfo &info);
        LTR114AdcConfig(const LTR114AdcConfig &adcCfg);

        INT correctionModeCode() const;
        INT fillLChTable(TLTR114_LCHANNEL *ltable) const;

        SyncMode m_syncMode;
        AutoCbrMode m_autoCbrMode;
        struct {
            AdcChMode Mode;
            int Range;
        } m_ch_params[adc_channels_cnt];

        friend class LTR114Config;
        friend class LTR114;
    };
}

Q_DECLARE_METATYPE(LQMeas::LTR114AdcConfig::AdcChRange);
Q_DECLARE_METATYPE(LQMeas::LTR114AdcConfig::AdcChMode);
Q_DECLARE_METATYPE(LQMeas::LTR114AdcConfig::SyncMode);
Q_DECLARE_METATYPE(LQMeas::LTR114AdcConfig::AutoCbrMode);



#endif // LQMEAS_LTR114ADCCONFIG_H
