#ifndef LQMEAS_LTR24ADCCONFIG_H
#define LQMEAS_LTR24ADCCONFIG_H

#include "lqmeas/ifaces/in/adc/DevAdcConfig.h"

namespace LQMeas {
    class LTR24AdcConfig : public DevAdcConfig {
        Q_OBJECT
    public:
        enum class ChMode {
            Diff,
            ICP
        };

        enum class AcMode {
            AcDc,
            AcOnly
        };

        enum class AdcDataFormat {
            Format_20,
            Format_24
        };

        enum class AdcChRange {
            Diff_10 = 0,
            Diff_2 = 1,

            ICP_5 = 0,
            ICP_1 = 1,
        };

        enum class AdcFreq {
            Freq_117K = 0,
            Freq_78K  = 1,
            Freq_58K  = 2,
            Freq_39K  = 3,
            Freq_29K  = 4,
            Freq_19K  = 5,
            Freq_14K  = 6,
            Freq_9K7  = 7,
            Freq_7K3  = 8,
            Freq_4K8  = 9,
            Freq_3K6  = 10,
            Freq_2K4  = 11,
            Freq_1K8  = 12,
            Freq_1K2  = 13,
            Freq_915  = 14,
            Freq_610  = 15
        };

        static const int adc_channels_cnt = 4;

        double adcFreq() const override;
        bool adcChEnabled(int ch) const override {return params.Ch[ch].enabled;}
        int adcChRangeNum(int ch) const override { return params.Ch[ch].range; }
        AdcChRange adcChRange(int ch) const {return static_cast<AdcChRange>(adcChRangeNum(ch));}
        ChMode adcChMode(int ch) const {return params.Ch[ch].mode;}
        AcMode adcChAcMode(int ch) const {return params.Ch[ch].ac_mode;}
        int adcFreqNum() const {return params.freq_num;}
        AdcFreq adcFreqCode() const {return static_cast<AdcFreq>(adcFreqNum());}
        AdcDataFormat adcDataFormat() const {return params.data_fmt;}
        bool adcTestModesEnabled() const {return params.test_modes_en;}

        /* возвращает максимально количество каналов, которое можно разрешить
         * для текущих настроек модуля */
        int adcMaxEnabledChCnt() const;

        bool adcChSupportMeasDC(int ch) const override;

        static int typeAdcRangeNum(LTR24AdcConfig::AdcChRange range) {return static_cast<int>(range);}
        static int typeAdcFreqNum(LTR24AdcConfig::AdcFreq freq) { return static_cast<int>(freq);}
        static double typeAdcFreqVal(LTR24AdcConfig::AdcFreq freq);
    public Q_SLOTS:
        void adcSetChEnabled(int ch, bool en);
        void adcSetChRange(int ch, AdcChRange range);
        void adcSetChRangeNum(int ch, int range_num);
        void adcSetChMode(int ch, ChMode mode);
        void adcSetChAcMode(int ch, AcMode mode);
        void adcSetFreqNum(int freq_num);
        void adcSetFreqCode(AdcFreq freq_code) {
            adcSetFreqNum(typeAdcFreqNum(freq_code));
        }
        void adcSetDataFormat(AdcDataFormat format);
        void adcSetTestModesEnabled(bool en);
    protected:
        void protSave(QJsonObject &cfgObj) const override;
        void protLoad(const QJsonObject &cfgObj) override;
        void protUpdateInfo(const DeviceTypeInfo *info) override ;
    private:
        LTR24AdcConfig(const DevAdcInfo &info);
        LTR24AdcConfig(const LTR24AdcConfig &cfg);

        static int defaultRangeNum() {return typeAdcRangeNum(AdcChRange::Diff_10);}
        static int defaultAdcFreqNum() {return typeAdcFreqNum(AdcFreq::Freq_9K7);}

        struct {
            int           freq_num;
            AdcDataFormat data_fmt;
            bool          test_modes_en;
            struct {
                bool      enabled;
                int       range;
                ChMode    mode;
                AcMode  ac_mode;
            } Ch[adc_channels_cnt];
        } params;

        friend class LTR24Config;
    };
}


Q_DECLARE_METATYPE(LQMeas::LTR24AdcConfig::ChMode);
Q_DECLARE_METATYPE(LQMeas::LTR24AdcConfig::AcMode);
Q_DECLARE_METATYPE(LQMeas::LTR24AdcConfig::AdcDataFormat);
Q_DECLARE_METATYPE(LQMeas::LTR24AdcConfig::AdcChRange);
Q_DECLARE_METATYPE(LQMeas::LTR24AdcConfig::AdcFreq);

#endif // LQMEAS_LTR24ADCCONFIG_H
