#include "LTR25Info.h"
#include <QJsonObject>
#include "lqmeas/StdConfigKeys.h"

namespace LQMeas {
    LTR25Info::LTR25Info(const LTR25TypeInfo &type, const QString &serial, int pld_ver,
                         int fpga_ver, int board_rev, bool icp_ext_bw) :
        DeviceInfo{type, serial},
        m_pld_ver{pld_ver},
        m_fpga_ver{fpga_ver},
        m_board_revision{board_rev},
        m_icp_ext_bw{icp_ext_bw} {

    }

    LTR25Info::LTR25Info(const LTR25Info &info) :
        DeviceInfo{info},
        m_pld_ver{info.m_pld_ver},
        m_fpga_ver{info.m_fpga_ver},
        m_board_revision{info.m_board_revision},
        m_icp_ext_bw{info.m_icp_ext_bw} {

    }

    void LTR25Info::protSave(QJsonObject &infoObj) const {
        infoObj[StdConfigKeys::pldVer()] = m_pld_ver;
        infoObj[StdConfigKeys::fpgaVer()] = m_fpga_ver;
        infoObj[StdConfigKeys::boardRev()] = m_board_revision;
        infoObj[StdConfigKeys::ipcExtBwLF()] = m_icp_ext_bw;
    }

    void LTR25Info::protLoad(const QJsonObject &infoObj) {
        m_pld_ver = infoObj[StdConfigKeys::pldVer()].toInt();
        m_fpga_ver = infoObj[StdConfigKeys::fpgaVer()].toInt();
        m_board_revision = infoObj[StdConfigKeys::boardRev()].toInt();
        m_icp_ext_bw = infoObj[StdConfigKeys::ipcExtBwLF()].toBool(true);
    }


}


bool LQMeas::LTR25Info::supportTEDS() const {
    return !((m_board_revision < 2) || (m_fpga_ver < 8));
}
