#include "LTR27AdcConfig.h"
#include "lqmeas/StdConfigKeys.h"
#include <QJsonObject>
#include <QJsonArray>
#include "ltr/include/ltr27api.h"

namespace LQMeas {
    static const QLatin1String cfgkey_ch_enabled         {StdConfigKeys::enabled()};
    static const QLatin1String cfgkey_channels_arr       {StdConfigKeys::channels()};
    static const QLatin1String cfgkey_adc_freq           {StdConfigKeys::adcFreq()};

    LTR27AdcConfig::LTR27AdcConfig(const DevAdcInfo &info) : DevAdcConfig{info} {
        memset(&params, 0, sizeof(params));
        params.FreqAdc = results.FreqAdc = adcDefaultFreq();
    }

    LTR27AdcConfig::LTR27AdcConfig(const LTR27AdcConfig &cfg) : DevAdcConfig{cfg} {
        memcpy(&params, &cfg.params, sizeof(params));
        memcpy(&results, &cfg.results, sizeof(results));
    }

    void LTR27AdcConfig::adcSetChEnabled(int ch, bool en) {
        if (params.Ch[ch].Enabled != en) {
            params.Ch[ch].Enabled = en;
            notifyChEnableStateChanged(ch);
            notifyConfigChanged();
        }
    }

    void LTR27AdcConfig::adcSetFreq(double freq) {
         if (params.FreqAdc != freq) {
             params.FreqAdc = freq;
             notifyAdcFreqChanged();
             notifyChFreqChanged();
             notifyConfigChanged();
         }

    }

    void LTR27AdcConfig::protSave(QJsonObject &cfgObj) const {
        QJsonArray chArray;
        for (int ch=0; ch < LTR27TypeInfo::adc_channels_cnt; ++ch) {
            QJsonObject chObj;
            chObj[cfgkey_ch_enabled] = params.Ch[ch].Enabled;
            chArray.append(chObj);
        }
        cfgObj[cfgkey_channels_arr] = chArray;
        cfgObj[cfgkey_adc_freq] = params.FreqAdc;
    }

    void LTR27AdcConfig::protLoad(const QJsonObject &cfgObj) {
        const QJsonArray &chArray = cfgObj[cfgkey_channels_arr].toArray();
        int ch_cnt = chArray.size();
        for (int ch=0; (ch < ch_cnt) && (ch < LTR27TypeInfo::adc_channels_cnt); ++ch) {
            const QJsonObject chObj = chArray.at(ch).toObject();
            params.Ch[ch].Enabled = chObj[cfgkey_ch_enabled].toBool();
        }
        params.FreqAdc = cfgObj[cfgkey_adc_freq].toDouble(adcDefaultFreq());
    }

    void LTR27AdcConfig::protUpdate() {
        DevAdcConfig::protUpdate();
        LTR27_FindAdcFreqParams(params.FreqAdc, nullptr, &results.FreqAdc);
    }
}
