#ifndef LQMEAS_LTR34OUTCONFIG_H
#define LQMEAS_LTR34OUTCONFIG_H

#include "lqmeas/ifaces/out/DevOutSyncConfig.h"

namespace LQMeas {
    class LTR34OutConfig : public DevOutSyncConfig {
        Q_OBJECT
    public:
        bool outSyncGenModeEnabled() const {return params.syncMode;}
        void outSetSyncModeEnabled(bool en);

        bool outExternalStart() const {return params.externalStart;}
        void outSetExternalStart(bool en);

        void outSyncSetGenFreq(double val);
        double outSyncGenFreq() const override {return results.OutFreq;}

        void outDacSetChRangeNum(int ch, int range);
        int outDacChRangeNum(int ch) const override {return params.Chs[ch].range;}

        bool outDacChSyncModeEnabled(int ch) const override { Q_UNUSED(ch) return params.syncMode;}
        bool outDigChSyncModeEnabled(int ch) const override { Q_UNUSED(ch) return false;}

        bool outSyncEchoEnabled() const override {return params.echoEnabled;}
        void outSyncSetEchoEnabled(bool en);
    protected:
        void protSave(QJsonObject &cfgObj) const override;
        void protLoad(const QJsonObject &cfgObj) override;
        void protUpdate() override;
    private:
        static const int max_dac_ch_cnt = 8;

        friend class LTR34Config;
        LTR34OutConfig(const DevOutInfo &info);
        LTR34OutConfig(const LTR34OutConfig &outCfg);

        struct {
            struct {
                int range;
            } Chs[max_dac_ch_cnt];
            bool syncMode;
            bool externalStart;
            bool echoEnabled;
            double OutFreq;
        } params;


        struct {
            double OutFreq;
        } results;
    };
}

#endif // LQMEAS_LTR34OUTCONFIG_H
