#include "LTR41.h"
#include "LTR41Info.h"
#include "LTR41Config.h"
#include "lqmeas/lqtdefs.h"
#include "lqmeas/StdErrors.h"
#include "lqmeas/devs/LTR/service/LTRServiceRef.h"
#include "lqmeas/devs/LTR/crates/LTRCrate.h"
#include "lqmeas/devs/DeviceRef.h"

namespace LQMeas {
    LTR41::LTR41(LTRCrate *crate, int slot, QObject *parent) :
        LTRModule{crate, slot, typeModuleID, new LTR41Config{}, LTR41Info{}, parent} {

        LTR41_Init(&m_hnd);
    }

    LTR41::~LTR41() {
        LTR41_Close(&m_hnd);
    }

    bool LTR41::isOpened() const {
        return LTR41_IsOpened(&m_hnd) == LTR_OK;
    }

    QString LTR41::errorString(int err) const {
        return QSTRING_FROM_CSTR(LTR41_GetErrorString(err));
    }

    const LTR41Config &LTR41::devspecConfig() const {
        return static_cast<const LTR41Config &>(config());
    }

    const LTR41Info &LTR41::devspecInfo() const {
        return static_cast<const LTR41Info&>(devInfo());
    }

    TLTR *LTR41::channel() const {
        return &m_hnd.Channel;
    }

    void LTR41::protOpen(OpenFlags flags, LQError &err) {
        Q_UNUSED(flags)
        INT ltr_err = LTR41_Open(&m_hnd,
                                 static_cast<INT>(serviceRef().ltrdIPv4Addr()),
                                 serviceRef().ltrdTcpPort(),
                                 ltrCrateRef().devInfo().serial().toLatin1(),
                                 slot());

        if (ltr_err == LTR_OK) {
            setDeviceInfo(LTR41Info{LTR41TypeInfo::defaultInfo(),
                                    QSTRING_FROM_CSTR(m_hnd.ModuleInfo.Serial),
                                    QSTRING_FROM_CSTR(m_hnd.ModuleInfo.FirmwareVersion)});
        }

        if (ltr_err != LTR_OK) {
            LTR41_Close(&m_hnd);
            getError(ltr_err, err);
        }
    }

    void LTR41::protClose(LQError &err) {
        getError(LTR41_Close(&m_hnd), err);
    }

    void LTR41::protConfigure(const DeviceConfig &cfg, LQError &err) {
        const LTR41Config *setCfg = qobject_cast<const LTR41Config *>(&cfg);
        if (setCfg) {
            getError(LTR41_Config(&m_hnd), err);
        } else {
            err = StdErrors::InvalidConfigType();
        }
    }

    void LTR41::protInAsyncDig(unsigned &val, LQError &err) {
        WORD rd_data;
        INT err_code = LTR41_ReadPort(&m_hnd, &rd_data);
        if (err_code == LTR_OK) {
            val = rd_data;
        } else {
            getError(err_code, err);
        }
    }
}
