#ifndef LQMEAS_LTR43_H
#define LQMEAS_LTR43_H

#include "ltr/include/ltr43api.h"
#include "lqmeas/devs/LTR/modules/LTRModule.h"
#include "lqmeas/ifaces/in/dig/DevInAsyncDig.h"
#include "lqmeas/ifaces/out/DevOutAsyncDigSwMask.h"
#include <QMutex>

namespace LQMeas {
    class LTR43Config;
    class LTR43Info;

    class LTR43 : public LTRModule, public DevInAsyncDig, public DevOutAsyncDigSwMask {
        Q_OBJECT
    public:
        static const quint16 typeModuleID {LTR_MID_LTR43};

        ~LTR43() override;
        bool isOpened() const override;

        DevOutAsyncDig *devOutAsyncDig() override {
            return static_cast<DevOutAsyncDig*>(this);
        }
        DevInAsyncDig *devInAsyncDig() override {
            return static_cast<DevInAsyncDig*>(this);
        }

        QString errorString(int err) const override;



        const LTR43Config &devspecConfig() const;
        const LTR43Info &devspecInfo() const;

        TLTR43 *rawHandle() {return &m_hnd;}
        const TLTR43 *rawHandle() const {return &m_hnd;}
    protected:
        TLTR* channel() const override;

        void protOpen(OpenFlags flags, LQError &err) override;
        void protClose(LQError &err) override;
        void protConfigure(const DeviceConfig &cfg, LQError &err) override;

        void protInAsyncDig(unsigned &val, LQError &err) override;
        void protOutAsyncDigAll(unsigned val, LQError &err) override;
    private:
        static int portCfgWord(const LTR43Config *cfg, int port_idx);

        explicit LTR43(LTRCrate *crate, int slot, QObject *parent = nullptr);
        mutable TLTR43 m_hnd;

        friend class LTRResolver;
        /* Используем мьютекс для возможности читать значения цифровых линий
         * из одного потока, а писать - из другого */
        mutable QMutex m_io_mutex;
    };
}

#endif // LQMEAS_LTR43_H
