#include "LTR43Config.h"
#include "LTR43.h"
#include "LTR43TypeInfo.h"
#include <QJsonObject>
#include <QJsonArray>
#include "lqmeas/EnumConfigKey.h"

namespace LQMeas {
    static const QLatin1String cfgkey_ports_arr {"Ports"};
    static const QLatin1String cfgkey_port_dir  {"Dir"};


    typedef EnumConfigKey<LTR43Config::Direction> LTR43PortDirKey;
    static const LTR43PortDirKey port_dirs[] = {
        {QStringLiteral("in"),          LTR43Config::Direction::In},
        {QStringLiteral("out"),         LTR43Config::Direction::Out},
        {LTR43PortDirKey::defaultKey(), LTR43Config::Direction::In},
    };

    QString LTR43Config::typeConfigName() {
        return LTR43TypeInfo::defaultInfo().deviceTypeName();
    }

    LTR43Config::LTR43Config() :
        m_in(this, *LTR43TypeInfo::defaultInfo().digin()),
        m_out(this, *LTR43TypeInfo::defaultInfo().out()) {

        for (int port_idx = 0; port_idx < ports_count; ++port_idx) {
            m_ports_dir[port_idx] = LTR43Config::Direction::In;
        }

        init();
    }

    LTR43Config::LTR43Config(const LTR43Config &cfg) :
        m_in{this, cfg.in()},
        m_out{this, cfg.out()} {

        for (int port_idx = 0; port_idx < ports_count; ++port_idx) {
            m_ports_dir[port_idx] = cfg.m_ports_dir[port_idx];
        }

        init();
    }

    LTR43Config::Direction LTR43Config::channelDirection(int chNum) const {
        return portDirection(chNum / channels_per_ports);
    }

    void LTR43Config::setPortDirection(int portNum, LTR43Config::Direction dir) {
        if ((dir == Direction::In) || (dir == Direction::Out)) {
            m_ports_dir[portNum] = dir;
            notifyConfigChanged();
            /** @todo update port availability ! */
        }
    }



    void LTR43Config::protSave(QJsonObject &cfgObj) const  {
        QJsonArray portsArr;
        for (int port_idx = 0; port_idx < ports_count; ++port_idx) {
            QJsonObject portObj;
            portObj[cfgkey_port_dir] = LTR43PortDirKey::getKey(port_dirs, m_ports_dir[port_idx]);
            portsArr.append(portObj);
        }
        cfgObj[cfgkey_ports_arr] = portsArr;
    }

    void LTR43Config::protLoad(const QJsonObject &cfgObj) {
        const QJsonArray &portsArr = cfgObj[cfgkey_ports_arr].toArray();
        for (int port_idx = 0; port_idx < ports_count; ++port_idx) {
            if (port_idx < portsArr.size()) {
                const QJsonObject portObj = portsArr.at(port_idx).toObject();
                m_ports_dir[port_idx] = LTR43PortDirKey::getValue(
                            port_dirs, portObj[cfgkey_port_dir].toString());
            } else {
                m_ports_dir[port_idx] = LTR43Config::Direction::In;
            }
        }
    }
}
