#ifndef LQMEAS_LTR43CONFIG_H
#define LQMEAS_LTR43CONFIG_H

#include "lqmeas/devs/DeviceConfig.h"
#include "LTR43InConfig.h"
#include "LTR43OutConfig.h"

namespace LQMeas {
    class LTR43Config : public DeviceConfig {
        Q_OBJECT
    public:
        enum class Direction {
            In,
            Out
        };

        const DevInDigConfig *inDigConfig() const override {
            return &m_in;
        }
        const DevOutConfig *outConfig() const override {
            return &m_out;
        }
        LTR43OutConfig &out() {return  m_out;}
        const LTR43OutConfig &out() const {return  m_out;}
        LTR43InConfig &in() {return  m_in;}
        const LTR43InConfig &in() const {return  m_in;}



        static int portsCount() {return ports_count;}


        static QString typeConfigName();
        QString configDevTypeName() const override {return typeConfigName();}

        DeviceConfig *clone() const override {
            return new LTR43Config(*this);
        }

        LTR43Config();
        LTR43Config(const LTR43Config &cfg);

        Direction portDirection(int portNum) const {return m_ports_dir[portNum];}
        Direction channelDirection(int chNum) const;

        void setPortDirection(int portNum, Direction dir);
    protected:
        void protSave(QJsonObject &cfgObj) const override;
        void protLoad(const QJsonObject &cfgObj) override;
    private:
        static const int ports_count = 4;
        static const int channels_per_ports = 8;


        Direction m_ports_dir[ports_count];
        LTR43InConfig m_in;
        LTR43OutConfig m_out;

    };
}

#endif // LQMEAS_LTR43CONFIG_H
