#include "LTRK511.h"
#include "LTRK511Config.h"
#include "LTRK511Info.h"
#include "lqmeas/lqtdefs.h"
#include "lqmeas/StdErrors.h"
#include "lqmeas/devs/LTR/service/LTRServiceRef.h"

namespace LQMeas {
    LTRK511::~LTRK511() {
        LTRK511_Close(&m_hnd);
    }

    bool LTRK511::isOpened() const  {
        return LTRK511_IsOpened(&m_hnd) == LTR_OK;
    }

    QString LTRK511::errorString(int err) const {
        return QSTRING_FROM_CSTR(LTRK511_GetErrorString(err));;
    }

    const LTRK511Config &LTRK511::devspecConfig() const {
        return static_cast<const LTRK511Config &>(config());
    }


    const LTRK511Info &LTRK511::devspecInfo() const {
        return static_cast<const LTRK511Info &>(devInfo());
    }

    void LTRK511::outSwState(int sw_num, LTRK511::OutSwState sw, LQError &err) {
        return getError(LTRK511_SetOutSwState(&m_hnd, sw_num, static_cast<BYTE>(sw)), err);
    }

    TLTR *LTRK511::channel() const {
        return &m_hnd.Channel;
    }

    void LTRK511::protOpen(Device::OpenFlags flags, LQError &err) {
        INT ltr_err = LTRK511_Open(&m_hnd,
                                 serviceRef().ltrdIPv4Addr(),
                                 serviceRef().ltrdTcpPort(),
                                 ltrCrateRef().devInfo().serial().toLatin1(),
                                 static_cast<WORD>(slot()));
        if (LTRK511_IsOpened(&m_hnd) == LTR_OK) {
            setDeviceInfo(LTRK511Info{LTRK511TypeInfo::defaultInfo(),
                                     QSTRING_FROM_CSTR(m_hnd.ModuleInfo.Serial),
                                     m_hnd.ModuleInfo.VerPLD});
        }

        if (ltr_err != LTR_OK) {
            if (!(flags & OpenFlag::Force) || (ltr_err == LTR_WARNING_MODULE_IN_USE))
                LTRK511_Close(&m_hnd);
            getError(ltr_err, err);
        }
    }

    void LTRK511::protClose(LQError &err) {
        getError(LTRK511_Close(&m_hnd), err);
    }

    void LTRK511::protConfigure(const DeviceConfig &cfg, LQError &err) {
        const LTRK511Config *setCfg {qobject_cast<const LTRK511Config *>(&cfg)};
        if (!setCfg) {
            err += StdErrors::InvalidConfigType();
        }
    }

    void LTRK511::protOutAsyncDigAll(unsigned val, LQError &err) {
        getError(LTRK511_SetRelayStates(&m_hnd, val & 0xFFFF), err);
    }

    void LTRK511::protOutAsyncDac(int ch, double val, LQError &err) {
        Q_UNUSED(ch)
        getError(LTRK511_SetDAC(&m_hnd, val, LTRK511_DAC_FLAG_CALIBR | LTRK511_DAC_FLAG_VALUE), err);
    }

    LTRK511::LTRK511(LTRCrate *crate, int slot, QObject *parent) :
        LTR01{crate, slot, typeModuleSubID, new LTRK511Config{}, LTRK511Info{}, parent},
        DevOutAsyncDac{this} {

        LTRK511_Init(&m_hnd);
    }

}
