#include "E502.h"
#include "e502api.h"
#include "E502Info.h"
#include "E502DeviceRefIPAddr.h"
#include "lqmeas/lqtdefs.h"
#include "netBrowser/E502DeviceRefNetSvc.h"
#include "netBrowser/E502NetSvcRecord.h"


namespace LQMeas {

    E502::~E502() {
        delete m_ipAddrRef;
    }

    QHostAddress E502::ipAddr() const {
        uint32_t addr;
        int err_code {E502_GetIpAddr(rawHandle(), &addr)};
        return err_code == X502_ERR_OK ?  QHostAddress{addr} : QHostAddress{};
    }

    int E502::outCycleGenMaxSize(const OutRamSignalGenerator &generator) const {
        int chCnt {generator.dacSignalsCount() + (generator.digSignalsCount() == 0 ? 0 : 1)};
        return  chCnt == 0 ? 0 : static_cast<int>(3.*1024*1024/chCnt);
    }

    DeviceRef *E502::createRef() const     {
        return m_ipAddrRef ? static_cast<DeviceRef*>(new E502DeviceRefIPAddr{devInfo(), *m_ipAddrRef})
               : m_netSvcRef ? static_cast<DeviceRef*>(new E502DeviceRefNetSvc{devInfo(), *m_netSvcRef})
               : m_svcRecord ? static_cast<DeviceRef*>(new E502DeviceRefNetSvc{devInfo(), m_svcRecord->instanceName(),
                                                                               defaultEthConnectionTout()})
               : x502::createRef();
    }

    const x502Info *E502::createInfo(const t_x502_info &info) const {
        return new E502Info{
            E502TypeInfo{info.devflags, true},
            QSTRING_FROM_CSTR(info.serial),
            info.fpga_ver,
            info.plda_ver,
            info.mcu_firmware_ver
        };
    }

    E502::E502(const t_x502_devrec &devrec) : x502{devrec, E502Info{}} {

    }

    E502::E502(const E502DeviceRefIPAddr &ipRef) : x502{ipRef.createDevrec(), E502Info{}},
        m_ipAddrRef{new E502DeviceRefIPAddr{ipRef}} {

    }

    E502::E502(const QSharedPointer<const E502NetSvcRecord> &svcRec, int conTout) :
        x502{svcRec->createDevrec(conTout), E502Info{}},
        m_svcRecord{svcRec} {

    }

    E502::E502(const QSharedPointer<const E502NetSvcRecord> &svcRec, const E502DeviceRefNetSvc &netRef)  :
        x502{netRef.createDevrec(*svcRec), E502Info{}},
        m_netSvcRef{new E502DeviceRefNetSvc{netRef}},
        m_svcRecord{svcRec} {

    }
}
