#ifndef LQMEAS_E502_H
#define LQMEAS_E502_H

#include "lqmeas/devs/x502/x502.h"
#include <QHostAddress>
#include "lqmeas_config.h"


namespace LQMeas {
    class x502Resolver;
    class E502DeviceRefIPAddr;
    class E502DeviceRefNetSvc;
    class E502NetSvcRecord;

    class E502 : public x502 {
        Q_OBJECT
    public:
        ~E502() override;
        QHostAddress ipAddr() const;

        int outCycleGenMaxSize(const OutRamSignalGenerator &generator) const override;

        const E502DeviceRefIPAddr *ipAddrRef() const {return m_ipAddrRef;}
        QSharedPointer<const E502NetSvcRecord> netRecord() const {return m_svcRecord;}
        DeviceRef *createRef() const override;

        static constexpr int defaultEthConnectionTout() {return 3000;}
    protected:
        const x502Info *createInfo(const t_x502_devrec *devrec) const;
        const x502Info *createInfo(const t_x502_info &info) const override;
    private:
        explicit E502(const t_x502_devrec &devrec);
        explicit E502(const E502DeviceRefIPAddr &ipRef);
        explicit E502(const QSharedPointer<const E502NetSvcRecord> &svcRec, int conTout);
        explicit E502(const QSharedPointer<const E502NetSvcRecord> &svcRec, const E502DeviceRefNetSvc &netRef);

        friend class x502Resolver;

        E502DeviceRefIPAddr *m_ipAddrRef {nullptr};
        E502DeviceRefNetSvc *m_netSvcRef {nullptr};
        QSharedPointer<const E502NetSvcRecord> m_svcRecord;
    };
}
#endif // E502_H
