#ifndef E502DEVICEREFIPADDR_H
#define E502DEVICEREFIPADDR_H

#include "x502api.h"
#include "lqmeas/devs/DeviceRef.h"
#include <QHostAddress>

namespace LQMeas {
    class E502DeviceRefIPAddr : public DeviceRef {
    public:
        explicit E502DeviceRefIPAddr(const DeviceInfo &devinfo,
                            const QHostAddress &ipAddr = QHostAddress{},
                            int conTout = defaultConnectionTimeout());
        E502DeviceRefIPAddr(const E502DeviceRefIPAddr &ipRef);
        explicit E502DeviceRefIPAddr(const DeviceInfo &devinfo, const E502DeviceRefIPAddr &ipRef);

        static const QString &typeRefTypeID();
        QString refTypeID() const override {return typeRefTypeID();}
        bool serialUsed() const override {return false;}


        const QHostAddress &ipAddr() const {return m_ipAddr;}
        int connectionTimeout() const {return m_conTout;}
        int cmdPort() const {return m_customPorts ? m_cmdPort : defaultCmdPort();}
        int dataPort() const {return m_customPorts ? m_dataPort : defaultDataPort(); }

        bool useCustomPorts() const {return m_customPorts;}
        int customCmdPort() const {return  m_cmdPort;}
        int customDataPort() const {return  m_dataPort;}

        void setIpAddr(const QHostAddress &addr) { m_ipAddr = addr; }
        void setConnectionTimeout(int toutMs) {m_conTout = toutMs;}
        void setUseCustomPorts(bool en) {m_customPorts = en;}
        void setCustomCmdPort(int port) {m_cmdPort = port;}
        void setCustomDataPort(int port) {m_dataPort = port;}


        static constexpr int defaultCmdPort() {return 11114;}
        static constexpr int defaultDataPort() {return 11115;}
        static int defaultConnectionTimeout();

        DevCheckResult checkDevice(const Device &device) const override;
        bool sameDevice(const DeviceRef &ref) const override;
        bool isAutoResolved() const override {return false;}

        void save(QJsonObject &refObj) const override;
        void load(const QJsonObject &refObj) override;

        DeviceRef *clone() const override;
        QString displayName() const override;
    protected:
        QString protKey() const override;
    private:
        t_x502_devrec createDevrec() const;

        QHostAddress m_ipAddr;
        int m_conTout;
        bool m_customPorts;
        int m_cmdPort;
        int m_dataPort;

        friend class E502;
    };
}

#endif // E502DEVICEREFIPADDR_H
