#ifndef E502DEVICEREFETHSVC_H
#define E502DEVICEREFETHSVC_H

#include "x502api.h"
#include "lqmeas/devs/DeviceRef.h"

namespace LQMeas {
    class E502NetSvcRecord;

    class E502DeviceRefNetSvc : public DeviceRef {
    public:
        E502DeviceRefNetSvc(const DeviceInfo &devinfo, const QString &instanceName = QString{},
                            int conTout = defaultConnectionTimeout());
        E502DeviceRefNetSvc(const E502DeviceRefNetSvc &ref);
        E502DeviceRefNetSvc(const DeviceInfo &devinfo, const E502DeviceRefNetSvc &ref);

        static const QString &typeRefTypeID();
        QString refTypeID() const override {return typeRefTypeID();}

        const QString &instanceName() const {return m_instanceName;}
        int connectionTimeout() const {return m_conTout;}
        bool serialUsed() const override {return false;}

        void setInstanceName(const QString &name) {m_instanceName = name;}
        void setConnectionTimeout(int toutMs) {m_conTout = toutMs;}

        static int defaultConnectionTimeout();

        bool checkNetSvcRecord(const E502NetSvcRecord &rec) const;

        DevCheckResult checkDevice(const Device &device) const override;
        bool sameDevice(const DeviceRef &ref) const override;

        void save(QJsonObject &refObj) const override;
        void load(const QJsonObject &refObj) override;

        DeviceRef *clone() const override;
        QString displayName() const override;
    protected:
        QString protKey() const override;
    private:
        t_x502_devrec createDevrec(const E502NetSvcRecord &rec) const;

        QString m_instanceName;
        int m_conTout;

        friend class E502;
    };
}

#endif // E502DEVICEREFETHSVC_H
