#include "E502NetSvcRecord.h"

#include "E502NetSvcRecord.h"
#include "../E502.h"
#include "../E502TypeInfo.h"


namespace LQMeas {

    QString E502NetSvcRecord::instanceName() const {
        char name[X502_INSTANCE_NAME_SIZE];
        QString ret;
        if (E502_EthSvcRecordGetInstanceName(m_hnd, name) == X502_ERR_OK) {
            ret = QString::fromUtf8(name);
        }
        return ret;
    }

    QString E502NetSvcRecord::deviceTypeName() const {
        return E502TypeInfo::name();
    }

    QString E502NetSvcRecord::deviceSerial() const {
        char serial[X502_SERIAL_SIZE];
        QString ret;
        if (E502_EthSvcRecordGetDevSerial(m_hnd, serial) == X502_ERR_OK) {
            ret = QString::fromLatin1(serial);
        }
        return ret;

    }

    QHostAddress E502NetSvcRecord::hostAddress() const {
        if (m_addr.isNull()) {
            uint32_t addr;
            if (E502_EthSvcRecordResolveIPv4Addr(m_hnd, &addr, defaultAddrResolveTout()) == X502_ERR_OK) {
                m_addr = QHostAddress(addr);
            }
        }
        return m_addr;
    }

    bool E502NetSvcRecord::isEqual(const DeviceNetSvcRecord &rec) const {
        bool eq = false;
        if (rec.deviceTypeName() == E502TypeInfo::name()) {
            const E502NetSvcRecord &e502_rec = static_cast<const E502NetSvcRecord &>(rec);
            eq = E502_EthSvcRecordIsSameInstance(m_hnd, e502_rec.m_hnd) == X502_ERR_OK ? true : false;
        }
        return  eq;
    }

    E502NetSvcRecord::E502NetSvcRecord(t_e502_eth_svc_record_hnd hnd) {
        m_hnd = hnd;
    }

    t_x502_devrec E502NetSvcRecord::createDevrec(int connectionTout) const {
        t_x502_devrec devrec;
        E502_MakeDevRecordByEthSvc(&devrec, m_hnd, 0, static_cast<uint32_t>(connectionTout));
        return  devrec;
    }

    E502NetSvcRecord::~E502NetSvcRecord() {
        E502_EthSvcRecordFree(m_hnd);
    }


}
