#include "E502NetworkBrowser.h"
#include "E502NetSvcRecord.h"
#include "../E502.h"
#include "e502api.h"

namespace LQMeas {
    E502NetworkBrowser::E502NetworkBrowser() {

    }

    void E502NetworkBrowser::run() {
        t_e502_eth_svc_browse_hnd browse_hnd;
        int32_t err_code = E502_EthSvcBrowseStart(&browse_hnd, 0);
        if (err_code != X502_ERR_OK) {
            LQError err;
            E502::getError(err_code, err);
            setError(err, tr("Cannot start network browse for E502 modules"));
        } else {
            while ((err_code == X502_ERR_OK) && !stopIsRequested()) {
                t_e502_eth_svc_record_hnd svc_hnd;
                uint32_t event;
                err_code = E502_EthSvcBrowseGetEvent(browse_hnd, &svc_hnd, &event, nullptr, 100);
                if (err_code != X502_ERR_OK) {
                    LQError err;
                    E502::getError(err_code, err);
                    setError(err, tr("Error occured during wait for new browse event for E502 modules"));
                } else {
                    if (event != E502_ETH_SVC_EVENT_NONE) {
                        QSharedPointer<DeviceNetSvcRecord> rec(new E502NetSvcRecord(svc_hnd));

                        if (event == E502_ETH_SVC_EVENT_ADD) {
                            addRecord(rec);
                        } else if (event == E502_ETH_SVC_EVENT_CHANGED) {
                            changeRecord(rec);
                        } else if (event == E502_ETH_SVC_EVENT_REMOVE) {
                            removeRecord(rec);
                        }
                    }
                }
            }

            E502_EthSvcBrowseStop(browse_hnd);
        }
    }
}
