#include "x502AdcConfig.h"
#include "x502Config.h"
#include <QJsonObject>

namespace LQMeas {
    static const QLatin1String cfgkey_ch_hw_avg   {"DevAvg"};

    x502AdcConfig::x502AdcConfig(x502Config *devCfg, const DevAdcInfo &info) :
        DevAdcStdSeq32Config{info},
        m_devCfg{devCfg} {

        memset(&params, 0, sizeof(params));


        for (unsigned ch = 0; ch < adc_channels_cnt; ++ch) {
            params.Ch[ch].Avg = 1;
        }
    }

    x502AdcConfig::x502AdcConfig(x502Config *devCfg, const x502AdcConfig &adcCfg) :
        DevAdcStdSeq32Config{adcCfg},
        m_devCfg{devCfg} {

        memcpy(&params, &adcCfg.params, sizeof(params));
    }

    bool x502AdcConfig::adcExternalStart() const {
        return (m_devCfg->freqMode() != x502Config::SyncMode::Internal) ||
                (m_devCfg->startMode() != x502Config::SyncMode::Internal);
    }

    void x502AdcConfig::adcSetChAvg(int ch, int avg_cnt) {
        if (avg_cnt < 0)
            avg_cnt = 0;
        if (avg_cnt > adcChAvgMaxVal())
            avg_cnt = adcChAvgMaxVal();
        if (avg_cnt != params.Ch[ch].Avg) {
            params.Ch[ch].Avg = avg_cnt;
            notifyAdcFreqChanged();
            notifyConfigChanged();
        }
    }

    int x502AdcConfig::adcChAvgMaxVal() const     {
        return X502_LCH_AVG_SIZE_MAX;
    }

    void x502AdcConfig::adcChSave(int ch, QJsonObject &chObj) const {
        DevAdcStdSeq32Config::adcChSave(ch, chObj);
        chObj[cfgkey_ch_hw_avg] = params.Ch[ch].Avg;
    }

    void x502AdcConfig::adcChLoad(int ch, const QJsonObject &chObj) {
        DevAdcStdSeq32Config::adcChLoad(ch, chObj);
        int avg = chObj[cfgkey_ch_hw_avg].toInt(1);
        if (avg < 1)
            avg = 1;
        if (avg > adcChAvgMaxVal())
            avg = adcChAvgMaxVal();
        params.Ch[ch].Avg = avg;
    }

    void x502AdcConfig::adcAdjustFreq(double *adcFreq, double *AdcChFreq) {
        int max_avg = 1;
        double ref_freq = m_devCfg->refFreq();
        for (int ch = 0; ch < adc_channels_cnt; ++ch) {
            if (adcChEnabled(ch)) {
                int avg = params.Ch[ch].Avg;
                if (avg > max_avg)
                    max_avg = avg;
            }
        }

        if (*adcFreq > ref_freq/max_avg)
            *adcFreq = ref_freq/max_avg;

        X502_CalcAdcFreq(ref_freq, static_cast<uint32_t>(adcEnabledChCnt()),
                         adcFreq, AdcChFreq, nullptr, nullptr);
    }
}
