#ifndef LQMEAS_X502ADCCONFIG_H
#define LQMEAS_X502ADCCONFIG_H

#include "lqmeas/ifaces/in/adc/DevAdcStdSeq32Config.h"

namespace LQMeas {
    class x502Config;

    class x502AdcConfig : public DevAdcStdSeq32Config  {
        Q_OBJECT
    public:
        enum class AdcChRange {
            U_10  = 0,
            U_5   = 1,
            U_2   = 2,
            U_1   = 3,
            U_0_5 = 4,
            U_0_2 = 5,
        };


        bool adcExternalStart() const override;

        AdcChRange adcChRange(int ch) const {return static_cast<AdcChRange>(adcChRangeNum(ch));}
        int adcChAvg(int ch) const {return params.Ch[ch].Avg;}
        int adcChAvgMaxVal() const;

        static int typeAdcRangeNum(AdcChRange range) {return static_cast<int>(range);}
    public Q_SLOTS:
        void adcSetChRange(int ch, AdcChRange range) {
            adcSetChRangeNum(ch, typeAdcRangeNum(range));
        }
        void adcSetChAvg(int ch, int avg_cnt);
    protected:
        void adcAdjustFreq(double *adcFreq, double *AdcChFreq) override;

        void adcChSave(int ch, QJsonObject &chObj) const override;
        void adcChLoad(int ch, const QJsonObject &chObj) override;
    private:
        x502AdcConfig(x502Config *devCfg, const DevAdcInfo &info);
        x502AdcConfig(x502Config *devCfg, const x502AdcConfig &adcCfg);

        struct {
            struct {
                int Avg;
            } Ch[adc_channels_cnt];
        } params;


        x502Config *m_devCfg;

        friend class x502Config;
    };


}

#endif // LQMEAS_X502ADCCONFIG_H
