#ifndef LQMEAS_X502CONFIG_H
#define LQMEAS_X502CONFIG_H

#include "lqmeas/devs/DeviceConfig.h"
#include "x502AdcConfig.h"
#include "x502OutConfig.h"
#include "x502TypeInfo.h"
#include "x502api.h"



namespace LQMeas {
    class x502Config : public DeviceConfig {
        Q_OBJECT
    public:
        static const QString &typeConfigName();


        enum class SyncMode {
            Internal,
            ExternalMaster,
            SYN1Rise,
            SYN1Fall,
            SYN2Rise,
            SYN2Fall
        };

        enum class RefFreq {
            Freq_2000KHz = 2000000,
            Freq_1500KHz = 1500000
        };


        const DevAdcConfig *adcConfig() const override {
            return &m_adc;
        }
        const DevOutConfig *outConfig() const override {
            return &m_out;
        }
        const DevOutSyncConfig *outSyncConfig() const override {
            return &m_out;
        }

        x502AdcConfig &adc() {return  m_adc;}
        const x502AdcConfig &adc() const {return  m_adc;}
        x502OutConfig &out() {return  m_out;}
        const x502OutConfig &out() const {return  m_out;}


        QString configDevTypeName() const override {return typeConfigName();}
        DeviceConfig *clone() const override {
            return new x502Config(*this);
        }

        x502Config();
        x502Config(const x502Config &cfg);

        SyncMode freqMode() const {return params.Sync.FreqMode;}
        SyncMode startMode() const {return params.Sync.StartMode;}
        RefFreq  refFreqInternal() const {return params.Sync.RefFreqInternal;}
        double   refFreqExternal() const {return params.Sync.RefFreqExternal;}

        static  double externalRefFreqMax();
        bool isRefFreqInternal() const {return params.Sync.FreqMode == SyncMode::Internal;}

        /* текущее значение опорной частоты (на основе настроек
         * внутренней или внешней опорной частоты в зависимости от freqMode) */
        double refFreq() const;

        uint32_t pullups() const {return params.Pullups;}

        bool bfIsEnabled() const {return params.Blackfin.Enabled;}

        QString bfFirmwareFilename() const { return params.Blackfin.FileName;}

        static double typeInternalRefFreqVal(RefFreq freq) {
            return static_cast<double>(freq);
        }
    public Q_SLOTS:
        void setFreqMode(SyncMode mode);
        void setStartMode(SyncMode mode);
        void setRefFreqInternal(RefFreq val);
        void setRefFreqExternal(double val);

        void setPullups(uint32_t pullups_flags);

        void setBfEnalbed(bool en);
        void setBfFirmwareFilename(QString filename);
    protected:
        void protSave(QJsonObject &cfgObj) const override;
        void protLoad(const QJsonObject &cfgObj) override;
        void protUpdate() override;

    private:
        x502AdcConfig m_adc;
        x502OutConfig m_out;

        struct {
            struct {
                SyncMode FreqMode;
                SyncMode StartMode;
                RefFreq  RefFreqInternal;
                double   RefFreqExternal;
            } Sync;

            uint32_t Pullups;



            struct {
                bool Enabled;
                QString FileName;
            } Blackfin;
        } params;

        struct {
            double DinFreq;
        } results;
    };
}

Q_DECLARE_METATYPE(LQMeas::x502Config::SyncMode);
Q_DECLARE_METATYPE(LQMeas::x502Config::RefFreq);

#endif // LQMEAS_X502CONFIG_H
