#include "x502TypeInfo.h"
#include "x502api.h"

static double f_ranges[] = {10.,5.,2.,1.,0.5, 0.2};

namespace LQMeas {

    const x502TypeInfo &x502TypeInfo::defaultInfo() {
        static const x502TypeInfo info{X502_DEVFLAGS_BF_PRESENT | X502_DEVFLAGS_DAC_PRESENT | X502_DEVFLAGS_GAL_PRESENT};
        return info;
    }

    int x502TypeInfo::adcChRangesCnt(int ch_num, int unit_mode_num) const {
        Q_UNUSED(ch_num) Q_UNUSED(unit_mode_num)
        return sizeof(f_ranges)/sizeof(f_ranges[0]);
    }

    double x502TypeInfo::adcChRangeMaxVal(int ch_num, int range, int unit_mode_num) const {
        Q_UNUSED(ch_num) Q_UNUSED(unit_mode_num)
        return f_ranges[range];
    }

    double x502TypeInfo::adcChRangeMinVal(int ch_num, int range, int unit_mode_num) const {
        Q_UNUSED(ch_num) Q_UNUSED(unit_mode_num)
        return -f_ranges[range];
    }

    double x502TypeInfo::outSyncGenFreqMax() const {
        return X502_REF_FREQ_2000KHZ/X502_OUT_FREQ_DIV_MIN;
    }

    int x502TypeInfo::outDacChannelsCnt() const {
        return m_dac_present ? dac_max_channels_cnt : 0;
    }

    int x502TypeInfo::outDigChannelsCnt() const {
        return dout_max_channels_cnt;
    }

    double x502TypeInfo::outDacChRangeMaxVal(int ch, int range) const {
        Q_UNUSED(ch) Q_UNUSED(range)
        return X502_DAC_RANGE;
    }

    double x502TypeInfo::outDacChRangeMinVal(int ch, int range) const {
        Q_UNUSED(ch) Q_UNUSED(range)
        return -X502_DAC_RANGE;
    }

    QList<const DeviceTypeInfo *> x502TypeInfo::modificationList() const {
        return QList<const DeviceTypeInfo *>{};
    }

    x502TypeInfo::x502TypeInfo(unsigned devflags) {
        m_gal_present = devflags & X502_DEVFLAGS_GAL_PRESENT ? true : false;
        m_dac_present = devflags & X502_DEVFLAGS_DAC_PRESENT ? true : false;
        m_bf_present  = devflags & X502_DEVFLAGS_BF_PRESENT ? true : false;
        m_eth_present = devflags & X502_DEVFLAGS_IFACE_SUPPORT_ETH ? true : false;
        m_industrial  = devflags & X502_DEVFLAGS_INDUSTRIAL ? true : false;
    }
}
