#ifndef LQMEAS_X502TYPEINFO_H
#define LQMEAS_X502TYPEINFO_H

#include "lqmeas/devs/DeviceTypeInfo.h"
#include "lqmeas/ifaces/in/adc/DevAdcInfo.h"
#include "lqmeas/ifaces/out/DevOutInfo.h"

namespace LQMeas {
    class x502TypeInfo : public DeviceTypeInfo, public DevAdcInfo, public DevOutInfo {
public:
        QString deviceTypeName() const {return QStringLiteral("x502");}
        static const x502TypeInfo &defaultInfo();

        bool galPresent() const {return m_gal_present;}
        bool dacPresent() const {return m_dac_present;}
        bool bfPresent() const {return m_bf_present;}
        bool ethPresent() const {return m_eth_present;}
        bool industrial() const {return m_industrial;}


        /* ----------------- DevAdcInfo -------------------------------------*/
        const DevAdcInfo *adc() const {return static_cast<const DevAdcInfo *>(this);}

        static const int adc_channels_cnt = 32;
        AdcType adcType() const {return AdcType::Sequential;}
        int adcChannelsCnt() const {return adc_channels_cnt;}

        double adcFreqMax() const {return 2000000;}
        bool adcIsChFreqConfigurable() const {return true;}

        int adcChRangesCnt(int ch_num, int unit_mode_num = 0) const;
        double adcChRangeMaxVal(int ch_num, int range, int unit_mode_num = 0) const;
        double adcChRangeMinVal(int ch_num, int range, int unit_mode_num = 0) const;

        /* ----------------- DevOutInfo -------------------------------------*/
        static const int dac_max_channels_cnt  = 2;
        static const int dout_max_channels_cnt = 16;

        const DevOutInfo *out() const {return static_cast<const DevOutInfo *>(this);}

        bool outDacSyncSupport() const {return m_dac_present;}
        bool outDigSyncSupport() const {return true;}

        bool outDacAsyncSupport() const {return m_dac_present;}
        bool outDigAsyncSupport() const {return true;}

        bool outDacSyncModeCfgPerCh() const {return true;}

        bool outSyncRamModeIsConfigurable() const {return true;}
        bool outSyncDacChGenModeIsConfigurable() const {return false;}
        bool outSyncDigChGenModeIsConfigurable() const {return false;}


        virtual double outSyncGenFreqMax() const;
        virtual bool outSyncPresetSupport() const {return true;}

        int outDacChannelsCnt() const;
        int outDigChannelsCnt() const;

        int outDacChRangesCnt(int ch) const{Q_UNUSED(ch) return 1;}
        double outDacChRangeMaxVal(int ch, int range) const;
        double outDacChRangeMinVal(int ch, int range) const;

         QList<const DeviceTypeInfo *> modificationList() const;
    protected:
        x502TypeInfo(unsigned flags);
    private:
        bool m_gal_present;
        bool m_dac_present;
        bool m_bf_present;
        bool m_eth_present;
        bool m_industrial;
    };
}

#endif // LQMEAS_X502TYPEINFO_H
