# Файл для включения в проект CMAKE.
# Перед включением библиотека Qt5 должна быть уже обнаружена и включен AUTOMOC и AUTOUIC
#
# На выходе возвращаются следующие переменные
#   LQMEAS_SOURCES              - исходные коды для включения в проект
#   LQMEAS_GENFILES             - сгенерированные файлы для включения в проект
#   LQMEAS_FILES                - все файлы (LQMEAS_SOURCES и LQMEAS_GENFILES)
#   LQMEAS_INCLUDE_DIRS         - директории заголовков для включения
#   LQMEAS_LIBRARIES            - библиотеки для линковки проекта
#   LQMEAS_LIBRARY_DIRS         - директории линковки
#   LQMEAS_COMPILE_DEFINITIONS  - определения для компилятора
#
# Перед включением могут быть установленны следующие конфигурационные переменные:
#   LQMEAS_DEVS                - список устройств, поддержка которых должна быть включена
#   LQMEAS_NO_GUI              - сборка с зависимостью только от QtCore
#   LQMEAS_USE_TEDS            - поддержка чтения с TEDS-датчиков


set(LQMEAS_DIR ${CMAKE_CURRENT_LIST_DIR})

set(LQMEAS_INCLUDE_DIRS ${LQMEAS_DIR}/.. ${LQMEAS_DIR}/subs/lqerror)

set(CMAKE_MODULE_PATH ${CMAKE_MODULE_PATH} "${LQMEAS_DIR}/cmake/Modules/")

set(LQMEAS_SOURCES
    ${LQMEAS_DIR}/subs/lqerror/LQError.h
    ${LQMEAS_DIR}/subs/lqerror/LQError.cpp
    ${LQMEAS_DIR}/StdErrors.h
    ${LQMEAS_DIR}/StdErrors.cpp

    ${LQMEAS_DIR}/lqtdefs.h
    ${LQMEAS_DIR}/EnumNamedValue.h
    ${LQMEAS_DIR}/EnumConfigKey.h

    ${LQMEAS_DIR}/StdConfigKeys.h
    ${LQMEAS_DIR}/StdConfigKeys.cpp

    ${LQMEAS_DIR}/misc/QListHelper.h
    ${LQMEAS_DIR}/misc/LQTypeReg.h

    ${LQMEAS_DIR}/units/Unit.h
    ${LQMEAS_DIR}/units/Unit.cpp
    ${LQMEAS_DIR}/units/UnitGroup.h
    ${LQMEAS_DIR}/units/UnitGroup.cpp
    ${LQMEAS_DIR}/units/UnitConverter.h
    ${LQMEAS_DIR}/units/UnitConverter.cpp
    ${LQMEAS_DIR}/units/UnitsStorage.h
    ${LQMEAS_DIR}/units/UnitsStorage.cpp
    ${LQMEAS_DIR}/units/std/UnitGroups.h
    ${LQMEAS_DIR}/units/std/UnitGroups.cpp
    ${LQMEAS_DIR}/units/std/Voltage.h
    ${LQMEAS_DIR}/units/std/Voltage.cpp
    ${LQMEAS_DIR}/units/std/Current.h
    ${LQMEAS_DIR}/units/std/Current.cpp
    ${LQMEAS_DIR}/units/std/Resistance.h
    ${LQMEAS_DIR}/units/std/Resistance.cpp
    ${LQMEAS_DIR}/units/std/Force.h
    ${LQMEAS_DIR}/units/std/Force.cpp
    ${LQMEAS_DIR}/units/std/Energy.h
    ${LQMEAS_DIR}/units/std/Energy.cpp
    ${LQMEAS_DIR}/units/std/Power.h
    ${LQMEAS_DIR}/units/std/Power.cpp
    ${LQMEAS_DIR}/units/std/ElectricCharge.h
    ${LQMEAS_DIR}/units/std/ElectricCharge.cpp
    ${LQMEAS_DIR}/units/std/Temperature.h
    ${LQMEAS_DIR}/units/std/Temperature.cpp
    ${LQMEAS_DIR}/units/std/Time.h
    ${LQMEAS_DIR}/units/std/Time.cpp
    ${LQMEAS_DIR}/units/std/Frequency.h
    ${LQMEAS_DIR}/units/std/Frequency.cpp
    ${LQMEAS_DIR}/units/std/RotationalSpeed.h
    ${LQMEAS_DIR}/units/std/RotationalSpeed.cpp
    ${LQMEAS_DIR}/units/std/Displacement.h
    ${LQMEAS_DIR}/units/std/Displacement.cpp
    ${LQMEAS_DIR}/units/std/Velocity.h
    ${LQMEAS_DIR}/units/std/Velocity.cpp
    ${LQMEAS_DIR}/units/std/Acceleration.h
    ${LQMEAS_DIR}/units/std/Acceleration.cpp
    ${LQMEAS_DIR}/units/std/Mass.h
    ${LQMEAS_DIR}/units/std/Mass.cpp
    ${LQMEAS_DIR}/units/std/Pressure.h
    ${LQMEAS_DIR}/units/std/Pressure.cpp
    ${LQMEAS_DIR}/units/std/PressureImpulse.h
    ${LQMEAS_DIR}/units/std/PressureImpulse.cpp
    ${LQMEAS_DIR}/units/std/MassFlowRate.h
    ${LQMEAS_DIR}/units/std/MassFlowRate.cpp
    ${LQMEAS_DIR}/units/std/VolumetricFlowRate.h
    ${LQMEAS_DIR}/units/std/VolumetricFlowRate.cpp
    ${LQMEAS_DIR}/units/std/Area.h
    ${LQMEAS_DIR}/units/std/Area.cpp
    ${LQMEAS_DIR}/units/std/Volume.h
    ${LQMEAS_DIR}/units/std/Volume.cpp
    ${LQMEAS_DIR}/units/std/Density.h
    ${LQMEAS_DIR}/units/std/Density.cpp
    ${LQMEAS_DIR}/units/std/Angle.h
    ${LQMEAS_DIR}/units/std/Angle.cpp
    ${LQMEAS_DIR}/units/std/Relative.h
    ${LQMEAS_DIR}/units/std/Relative.cpp
    ${LQMEAS_DIR}/units/std/RelativeDeformation.h
    ${LQMEAS_DIR}/units/std/RelativeDeformation.cpp
    ${LQMEAS_DIR}/units/std/Discrete.h
    ${LQMEAS_DIR}/units/std/Discrete.cpp
    ${LQMEAS_DIR}/units/std/Information.h
    ${LQMEAS_DIR}/units/std/Information.cpp
    ${LQMEAS_DIR}/units/std/Special.h
    ${LQMEAS_DIR}/units/std/Special.cpp
    ${LQMEAS_DIR}/units/std/Digital.h
    ${LQMEAS_DIR}/units/std/Digital.cpp

    ${LQMEAS_DIR}/log/Log.h
    ${LQMEAS_DIR}/log/Log.cpp
    ${LQMEAS_DIR}/log/LogLevel.h
    ${LQMEAS_DIR}/log/LogMessage.h



    ${LQMEAS_DIR}/devs/Device.h
    ${LQMEAS_DIR}/devs/Device.cpp
    ${LQMEAS_DIR}/devs/DeviceInterface.h
    ${LQMEAS_DIR}/devs/DeviceInterface.cpp
    ${LQMEAS_DIR}/devs/DeviceInfo.h
    ${LQMEAS_DIR}/devs/DeviceInfo.cpp
    ${LQMEAS_DIR}/devs/DeviceRef.h
    ${LQMEAS_DIR}/devs/DeviceRef.cpp
    ${LQMEAS_DIR}/devs/DeviceConfig.h
    ${LQMEAS_DIR}/devs/DeviceConfig.cpp
    ${LQMEAS_DIR}/devs/DeviceConfigIface.h
    ${LQMEAS_DIR}/devs/DeviceConfigIface.cpp
    ${LQMEAS_DIR}/devs/DeviceTypeInfo.h
    ${LQMEAS_DIR}/devs/DeviceTypeInfo.cpp
    ${LQMEAS_DIR}/devs/DeviceValidator.h
    ${LQMEAS_DIR}/devs/DeviceValidator.cpp
    ${LQMEAS_DIR}/devs/DeviceNameValidator.h
    ${LQMEAS_DIR}/devs/DeviceNameValidator.cpp
    ${LQMEAS_DIR}/devs/DeviceFrameReceiver.h
    ${LQMEAS_DIR}/devs/DeviceFrameSender.h
    ${LQMEAS_DIR}/devs/resolver/DevicesResolver.h
    ${LQMEAS_DIR}/devs/resolver/DevicesResolver.cpp

    ${LQMEAS_DIR}/sensors/Sensor.h
    ${LQMEAS_DIR}/sensors/Sensor.cpp
    ${LQMEAS_DIR}/sensors/SensorTypeInfo.h
    ${LQMEAS_DIR}/sensors/SensorTypeInfo.cpp


    ${LQMEAS_DIR}/ifaces/out/Signals/SignalType.h
    ${LQMEAS_DIR}/ifaces/out/Signals/SignalConfig.h
    ${LQMEAS_DIR}/ifaces/out/Signals/SignalConfig.cpp
    ${LQMEAS_DIR}/ifaces/out/Signals/SignalGenerator.h
    ${LQMEAS_DIR}/ifaces/out/Signals/SignalGenerator.cpp
    ${LQMEAS_DIR}/ifaces/out/Signals/SignalFabric.h
    ${LQMEAS_DIR}/ifaces/out/Signals/SignalFabric.cpp
    ${LQMEAS_DIR}/ifaces/out/Signals/Analog/AnalogSignalGenerator.h
    ${LQMEAS_DIR}/ifaces/out/Signals/Analog/AnalogSignalType.h
    ${LQMEAS_DIR}/ifaces/out/Signals/Analog/Const/AnalogSignalConst.h
    ${LQMEAS_DIR}/ifaces/out/Signals/Analog/Const/AnalogSignalConst.cpp
    ${LQMEAS_DIR}/ifaces/out/Signals/Analog/Const/AnalogSignalConstConfig.h
    ${LQMEAS_DIR}/ifaces/out/Signals/Analog/Const/AnalogSignalConstConfig.cpp
    ${LQMEAS_DIR}/ifaces/out/Signals/Analog/Const/AnalogSignalConstGenerator.h
    ${LQMEAS_DIR}/ifaces/out/Signals/Analog/Const/AnalogSignalConstGenerator.cpp
    ${LQMEAS_DIR}/ifaces/out/Signals/Analog/Sin/AnalogSignalSin.h
    ${LQMEAS_DIR}/ifaces/out/Signals/Analog/Sin/AnalogSignalSin.cpp
    ${LQMEAS_DIR}/ifaces/out/Signals/Analog/Sin/AnalogSignalSinConfig.h
    ${LQMEAS_DIR}/ifaces/out/Signals/Analog/Sin/AnalogSignalSinConfig.cpp
    ${LQMEAS_DIR}/ifaces/out/Signals/Analog/Sin/AnalogSignalSinGenerator.h
    ${LQMEAS_DIR}/ifaces/out/Signals/Analog/Sin/AnalogSignalSinGenerator.cpp
    ${LQMEAS_DIR}/ifaces/out/Signals/Analog/Pulse/AnalogSignalPulse.h
    ${LQMEAS_DIR}/ifaces/out/Signals/Analog/Pulse/AnalogSignalPulse.cpp
    ${LQMEAS_DIR}/ifaces/out/Signals/Analog/Pulse/AnalogSignalPulseConfig.h
    ${LQMEAS_DIR}/ifaces/out/Signals/Analog/Pulse/AnalogSignalPulseConfig.cpp
    ${LQMEAS_DIR}/ifaces/out/Signals/Analog/Pulse/AnalogSignalPulseGenerator.h
    ${LQMEAS_DIR}/ifaces/out/Signals/Analog/Pulse/AnalogSignalPulseGenerator.cpp
    ${LQMEAS_DIR}/ifaces/out/Signals/Analog/Ramp/AnalogSignalRamp.h
    ${LQMEAS_DIR}/ifaces/out/Signals/Analog/Ramp/AnalogSignalRamp.cpp
    ${LQMEAS_DIR}/ifaces/out/Signals/Analog/Ramp/AnalogSignalRampConfig.h
    ${LQMEAS_DIR}/ifaces/out/Signals/Analog/Ramp/AnalogSignalRampConfig.cpp
    ${LQMEAS_DIR}/ifaces/out/Signals/Analog/Ramp/AnalogSignalRampGenerator.h
    ${LQMEAS_DIR}/ifaces/out/Signals/Analog/Ramp/AnalogSignalRampGenerator.cpp
    ${LQMEAS_DIR}/ifaces/out/Signals/Analog/MultiPoint/AnalogSignalMultiPoint.h
    ${LQMEAS_DIR}/ifaces/out/Signals/Analog/MultiPoint/AnalogSignalMultiPoint.cpp
    ${LQMEAS_DIR}/ifaces/out/Signals/Analog/MultiPoint/AnalogSignalMultiPointConfig.h
    ${LQMEAS_DIR}/ifaces/out/Signals/Analog/MultiPoint/AnalogSignalMultiPointConfig.cpp
    ${LQMEAS_DIR}/ifaces/out/Signals/Analog/MultiPoint/AnalogSignalMultiPointGenerator.h
    ${LQMEAS_DIR}/ifaces/out/Signals/Analog/MultiPoint/AnalogSignalMultiPointGenerator.cpp
    ${LQMEAS_DIR}/ifaces/out/Signals/Analog/MultiPoint/AnalogSignalMultiPointConnector.h
    ${LQMEAS_DIR}/ifaces/out/Signals/Analog/MultiPoint/AnalogSignalMultiPointConnector.cpp
    ${LQMEAS_DIR}/ifaces/out/Signals/Analog/TimeSeq/AnalogSignalTimeSeq.h
    ${LQMEAS_DIR}/ifaces/out/Signals/Analog/TimeSeq/AnalogSignalTimeSeq.cpp
    ${LQMEAS_DIR}/ifaces/out/Signals/Analog/TimeSeq/AnalogSignalTimeSeqConfig.h
    ${LQMEAS_DIR}/ifaces/out/Signals/Analog/TimeSeq/AnalogSignalTimeSeqConfig.cpp
    ${LQMEAS_DIR}/ifaces/out/Signals/Analog/TimeSeq/AnalogSignalTimeSeqGenerator.h
    ${LQMEAS_DIR}/ifaces/out/Signals/Analog/TimeSeq/AnalogSignalTimeSeqGenerator.cpp

    ${LQMEAS_DIR}/ifaces/out/Signals/Discrete/DiscreteSignalType.h
    ${LQMEAS_DIR}/ifaces/out/Signals/Discrete/DiscreteSignalGenerator.h
    ${LQMEAS_DIR}/ifaces/out/Signals/Discrete/Pulse/DiscreteSignalPulse.h
    ${LQMEAS_DIR}/ifaces/out/Signals/Discrete/Pulse/DiscreteSignalPulse.cpp
    ${LQMEAS_DIR}/ifaces/out/Signals/Discrete/Pulse/DiscreteSignalPulseConfig.h
    ${LQMEAS_DIR}/ifaces/out/Signals/Discrete/Pulse/DiscreteSignalPulseConfig.cpp
    ${LQMEAS_DIR}/ifaces/out/Signals/Discrete/Pulse/DiscreteSignalPulseGenerator.h
    ${LQMEAS_DIR}/ifaces/out/Signals/Discrete/Pulse/DiscreteSignalPulseGenerator.cpp
    ${LQMEAS_DIR}/ifaces/out/Signals/Discrete/Const/DiscreteSignalConst.h
    ${LQMEAS_DIR}/ifaces/out/Signals/Discrete/Const/DiscreteSignalConst.cpp
    ${LQMEAS_DIR}/ifaces/out/Signals/Discrete/Const/DiscreteSignalConstConfig.h
    ${LQMEAS_DIR}/ifaces/out/Signals/Discrete/Const/DiscreteSignalConstConfig.cpp
    ${LQMEAS_DIR}/ifaces/out/Signals/Discrete/Const/DiscreteSignalConstGenerator.h
    ${LQMEAS_DIR}/ifaces/out/Signals/Discrete/Const/DiscreteSignalConstGenerator.cpp
    ${LQMEAS_DIR}/ifaces/out/Signals/Discrete/SinglePulseBurst/DiscreteSignalSinglePulseBurst.h
    ${LQMEAS_DIR}/ifaces/out/Signals/Discrete/SinglePulseBurst/DiscreteSignalSinglePulseBurst.cpp
    ${LQMEAS_DIR}/ifaces/out/Signals/Discrete/SinglePulseBurst/DiscreteSignalSinglePulseBurstConfig.h
    ${LQMEAS_DIR}/ifaces/out/Signals/Discrete/SinglePulseBurst/DiscreteSignalSinglePulseBurstConfig.cpp
    ${LQMEAS_DIR}/ifaces/out/Signals/Discrete/SinglePulseBurst/DiscreteSignalSinglePulseBurstGenerator.h
    ${LQMEAS_DIR}/ifaces/out/Signals/Discrete/SinglePulseBurst/DiscreteSignalSinglePulseBurstGenerator.cpp
    ${LQMEAS_DIR}/ifaces/out/Signals/Discrete/MultiPoint/DiscreteSignalMultiPoint.h
    ${LQMEAS_DIR}/ifaces/out/Signals/Discrete/MultiPoint/DiscreteSignalMultiPoint.cpp
    ${LQMEAS_DIR}/ifaces/out/Signals/Discrete/MultiPoint/DiscreteSignalMultiPointConfig.h
    ${LQMEAS_DIR}/ifaces/out/Signals/Discrete/MultiPoint/DiscreteSignalMultiPointConfig.cpp
    ${LQMEAS_DIR}/ifaces/out/Signals/Discrete/MultiPoint/DiscreteSignalMultiPointGenerator.h
    ${LQMEAS_DIR}/ifaces/out/Signals/Discrete/MultiPoint/DiscreteSignalMultiPointGenerator.cpp




    ${LQMEAS_DIR}/ifaces/out/SignalConverter/DevOutDacConverter.h
    ${LQMEAS_DIR}/ifaces/out/SignalConverter/DevOutDacConverter.cpp
    ${LQMEAS_DIR}/ifaces/out/SignalConverter/SignalConverter.h
    ${LQMEAS_DIR}/ifaces/out/SignalConverter/SignalConverter.cpp
    ${LQMEAS_DIR}/ifaces/out/SignalConverter/Linear/SignalConverterLinear.h
    ${LQMEAS_DIR}/ifaces/out/SignalConverter/Linear/SignalConverterLinear.cpp

    ${LQMEAS_DIR}/ifaces/out/DevOutInfo.h
    ${LQMEAS_DIR}/ifaces/out/DevOutInfo.cpp
    ${LQMEAS_DIR}/ifaces/out/DevOutConfig.h
    ${LQMEAS_DIR}/ifaces/out/DevOutConfig.cpp
    ${LQMEAS_DIR}/ifaces/out/DevOutSync.h
    ${LQMEAS_DIR}/ifaces/out/DevOutSync.cpp
    ${LQMEAS_DIR}/ifaces/out/DevOutSyncConfig.h
    ${LQMEAS_DIR}/ifaces/out/DevOutSyncConfig.cpp
    ${LQMEAS_DIR}/ifaces/out/DevOutSyncStatusTracker.h
    ${LQMEAS_DIR}/ifaces/out/DevOutSyncStatusTracker.cpp
    ${LQMEAS_DIR}/ifaces/out/DevOutAsyncDac.h
    ${LQMEAS_DIR}/ifaces/out/DevOutAsyncDac.cpp
    ${LQMEAS_DIR}/ifaces/out/DevOutAsyncDig.h
    ${LQMEAS_DIR}/ifaces/out/DevOutAsyncDig.cpp
    ${LQMEAS_DIR}/ifaces/out/DevOutAsyncDigSwMask.h
    ${LQMEAS_DIR}/ifaces/out/DevOutAsyncDigSwMask.cpp
    ${LQMEAS_DIR}/ifaces/out/OutRamSignalGenerator.h
    ${LQMEAS_DIR}/ifaces/out/OutRamSignalGenerator.cpp
    ${LQMEAS_DIR}/ifaces/out/DevOutSyncEchoTracker.h
    ${LQMEAS_DIR}/ifaces/out/DevOutSyncEchoTracker.cpp
    ${LQMEAS_DIR}/ifaces/out/SyncModes/DevOutSyncIfaceSend.h
    ${LQMEAS_DIR}/ifaces/out/SyncModes/DevOutSyncIfaceSend.cpp
    ${LQMEAS_DIR}/ifaces/out/SyncModes/DevOutSyncModeImpl.h
    ${LQMEAS_DIR}/ifaces/out/SyncModes/DevOutSyncModeImpl.cpp
    ${LQMEAS_DIR}/ifaces/out/SyncModes/stream/DevOutSyncIfaceStream.h
    ${LQMEAS_DIR}/ifaces/out/SyncModes/stream/DevOutSyncIfaceStream.cpp
    ${LQMEAS_DIR}/ifaces/out/SyncModes/stream/DevOutSyncModeImplStream.h
    ${LQMEAS_DIR}/ifaces/out/SyncModes/stream/DevOutSyncModeImplStream.cpp
    ${LQMEAS_DIR}/ifaces/out/SyncModes/stream/DevOutSyncStreamThread.h
    ${LQMEAS_DIR}/ifaces/out/SyncModes/stream/DevOutSyncStreamThread.cpp
    ${LQMEAS_DIR}/ifaces/out/SyncModes/cycle/DevOutSyncIfaceCycle.h
    ${LQMEAS_DIR}/ifaces/out/SyncModes/cycle/DevOutSyncIfaceCycle.cpp
    ${LQMEAS_DIR}/ifaces/out/SyncModes/cycle/DevOutSyncModeImplCycle.h
    ${LQMEAS_DIR}/ifaces/out/SyncModes/cycle/DevOutSyncModeImplCycle.cpp



    ${LQMEAS_DIR}/ifaces/in/adc/DevAdc.h
    ${LQMEAS_DIR}/ifaces/in/adc/DevAdc.cpp
    ${LQMEAS_DIR}/ifaces/in/adc/DevAdcInfo.h
    ${LQMEAS_DIR}/ifaces/in/adc/DevAdcInfo.cpp
    ${LQMEAS_DIR}/ifaces/in/adc/DevAdcConfig.h
    ${LQMEAS_DIR}/ifaces/in/adc/DevAdcConfig.cpp
    ${LQMEAS_DIR}/ifaces/in/adc/DevAdcSeqBaseConfig.h
    ${LQMEAS_DIR}/ifaces/in/adc/DevAdcSeqBaseConfig.cpp
    ${LQMEAS_DIR}/ifaces/in/adc/DevAdcStdSeq32Config.h
    ${LQMEAS_DIR}/ifaces/in/adc/DevAdcStdSeq32Config.cpp
    ${LQMEAS_DIR}/ifaces/in/adc/icp/DevAdcICPConfig.h
    ${LQMEAS_DIR}/ifaces/in/adc/icp/DevAdcICPConfig.cpp
    ${LQMEAS_DIR}/ifaces/in/adc/icp/DevAdcICPSensorRoutUpdater.h
    ${LQMEAS_DIR}/ifaces/in/adc/icp/DevAdcICPSensorRoutUpdater.cpp
    ${LQMEAS_DIR}/ifaces/in/adc/tare/DevAdcTare.h
    ${LQMEAS_DIR}/ifaces/in/adc/tare/DevAdcTare.cpp
    ${LQMEAS_DIR}/ifaces/in/adc/tare/DevAdcTareOp.h
    ${LQMEAS_DIR}/ifaces/in/adc/tare/DevAdcTarePoint.h
    ${LQMEAS_DIR}/ifaces/in/adc/tare/DevAdcTarePoint.cpp
    ${LQMEAS_DIR}/ifaces/in/adc/tare/DevAdcTareChCoefs.h
    ${LQMEAS_DIR}/ifaces/in/adc/tare/DevAdcTareChCoefs.cpp
    ${LQMEAS_DIR}/ifaces/in/adc/tare/DevAdcTareCoefType.h
    ${LQMEAS_DIR}/ifaces/in/adc/tare/DevAdcTareInfo.h
    ${LQMEAS_DIR}/ifaces/in/adc/tare/DevAdcTareInfo.cpp
    ${LQMEAS_DIR}/ifaces/in/dig/DevInDigInfo.h
    ${LQMEAS_DIR}/ifaces/in/dig/DevInDigInfo.cpp
    ${LQMEAS_DIR}/ifaces/in/dig/DevInDigConfig.h
    ${LQMEAS_DIR}/ifaces/in/dig/DevInDigConfig.cpp
    ${LQMEAS_DIR}/ifaces/in/dig/DevInAsyncDig.h
    ${LQMEAS_DIR}/ifaces/in/dig/DevInAsyncDig.cpp


    ${LQMEAS_DIR}/ifaces/sync/DevSyncMark.h
    ${LQMEAS_DIR}/ifaces/sync/DevSyncMark.cpp
    ${LQMEAS_DIR}/ifaces/sync/DevSyncMarksGen.h
    ${LQMEAS_DIR}/ifaces/sync/DevSyncMarksGen.cpp
    ${LQMEAS_DIR}/ifaces/sync/DevSyncMarksGenInfo.h
    ${LQMEAS_DIR}/ifaces/sync/DevSyncMarksGenInfo.cpp
    ${LQMEAS_DIR}/ifaces/sync/DevSyncMarksGenConfig.h
    ${LQMEAS_DIR}/ifaces/sync/DevSyncMarksGenConfig.cpp
    ${LQMEAS_DIR}/ifaces/sync/DevSyncMarksRecv.h
    ${LQMEAS_DIR}/ifaces/sync/DevSyncMarksRecv.cpp
    ${LQMEAS_DIR}/ifaces/sync/DevSyncMarksRecvInfo.h
    ${LQMEAS_DIR}/ifaces/sync/DevSyncMarksRecvInfo.cpp
    ${LQMEAS_DIR}/ifaces/sync/DevSyncMarksRecvConfig.h
    ${LQMEAS_DIR}/ifaces/sync/DevSyncMarksRecvConfig.cpp
   )


if(NOT LQMEAS_NO_GUI)
    set(LQMEAS_SOURCES ${LQMEAS_SOURCES}
        ${LQMEAS_DIR}/log/LogModel.h
        ${LQMEAS_DIR}/log/LogModel.cpp
        ${LQMEAS_DIR}/log/LogPanel.h
        ${LQMEAS_DIR}/log/LogPanel.cpp
        )
endif(NOT LQMEAS_NO_GUI)




set(LQMEAS_SOURCES ${LQMEAS_SOURCES}
    ${LQMEAS_DIR}/devs/resolver/netBrowser/DeviceNetSvcRecord.h
    ${LQMEAS_DIR}/devs/resolver/netBrowser/DeviceNetSvcRecord.cpp
    ${LQMEAS_DIR}/devs/resolver/netBrowser/DeviceNetworkBrowser.h
    ${LQMEAS_DIR}/devs/resolver/netBrowser/DeviceNetworkBrowser.cpp
    )



set(LTR_MODULES LTR11 LTR12 LTR22 LTR24 LTR25 LTR27 LTR34 LTR35 LTR41 LTR42 LTR43 LTR114 LTR212 LTR216 LTRT13 LTRS412 LTRK511)
# LTR51 LTR210



foreach(LTR_MODULE ${LTR_MODULES})
    list(FIND LQMEAS_DEVS ${LTR_MODULE} ${LTR_MODULE}_IDX)
    if(NOT ${LTR_MODULE}_IDX EQUAL -1)
        string(TOLOWER ${LTR_MODULE} LTR_MODULE_LOWER)

        set(LQMEAS_DEV_${LTR_MODULE} ON)
        set(LQMEAS_DEV_LTR           ON)

        set(LTR_MODULE_DIR ${LQMEAS_DIR}/devs/LTR/modules/${LTR_MODULE})
        include(${LTR_MODULE_DIR}/${LTR_MODULE}.cmake)

        set(LQMEAS_LTRAPI_COMPONENTS ${LQMEAS_LTRAPI_COMPONENTS} ${LTR_MODULE_LOWER}api)
    endif()
endforeach()

if(LQMEAS_DEV_LTR)

    set(LQMEAS_LTRAPI_COMPONENTS ${LQMEAS_LTRAPI_COMPONENTS} ltrapi)

    set(LQMEAS_SOURCES ${LQMEAS_SOURCES}
        ${LQMEAS_DIR}/devs/LTR/LTRNativeError.h
        ${LQMEAS_DIR}/devs/LTR/LTRNativeError.cpp
        ${LQMEAS_DIR}/devs/LTR/LTRResolver.h
        ${LQMEAS_DIR}/devs/LTR/LTRResolver.cpp
        ${LQMEAS_DIR}/devs/LTR/LTRModuleRef.h
        ${LQMEAS_DIR}/devs/LTR/LTRModuleRef.cpp
        ${LQMEAS_DIR}/devs/LTR/service/LTRService.h
        ${LQMEAS_DIR}/devs/LTR/service/LTRService.cpp
        ${LQMEAS_DIR}/devs/LTR/service/LTRServiceRef.h
        ${LQMEAS_DIR}/devs/LTR/service/LTRServiceRef.cpp
        ${LQMEAS_DIR}/devs/LTR/service/LTRServiceInfo.h
        ${LQMEAS_DIR}/devs/LTR/service/LTRServiceInfo.cpp
        ${LQMEAS_DIR}/devs/LTR/service/LTRServiceTypeInfo.h
        ${LQMEAS_DIR}/devs/LTR/service/LTRServiceTypeInfo.cpp
        ${LQMEAS_DIR}/devs/LTR/service/LTRServiceConfig.h
        ${LQMEAS_DIR}/devs/LTR/service/LTRServiceConfig.cpp
        ${LQMEAS_DIR}/devs/LTR/service/LTRServiceModuleBufConfig.h
        ${LQMEAS_DIR}/devs/LTR/service/LTRServiceModuleBufConfig.cpp
        ${LQMEAS_DIR}/devs/LTR/crates/LTRCrate.h
        ${LQMEAS_DIR}/devs/LTR/crates/LTRCrate.cpp
        ${LQMEAS_DIR}/devs/LTR/crates/LTRCrateRef.h
        ${LQMEAS_DIR}/devs/LTR/crates/LTRCrateRef.cpp
        ${LQMEAS_DIR}/devs/LTR/crates/LTRCrateTypeInfo.h
        ${LQMEAS_DIR}/devs/LTR/crates/LTRCrateTypeInfo.cpp
        ${LQMEAS_DIR}/devs/LTR/crates/LTRCrateInfo.h
        ${LQMEAS_DIR}/devs/LTR/crates/LTRCrateInfo.cpp
        ${LQMEAS_DIR}/devs/LTR/crates/LTRCrateConfig.h
        ${LQMEAS_DIR}/devs/LTR/crates/LTRCrateConfig.cpp
        ${LQMEAS_DIR}/devs/LTR/crates/LTRCrateSyncConfig.h
        ${LQMEAS_DIR}/devs/LTR/crates/LTRCrateSyncConfig.cpp
        ${LQMEAS_DIR}/devs/LTR/modules/LTRModule.h
        ${LQMEAS_DIR}/devs/LTR/modules/LTRModule.cpp
        ${LQMEAS_DIR}/devs/LTR/modules/LTRModuleFrameReceiver.h
        ${LQMEAS_DIR}/devs/LTR/modules/LTRModuleFrameReceiver.cpp
        ${LQMEAS_DIR}/devs/LTR/modules/LTRModuleRawWordsTracker.h
        ${LQMEAS_DIR}/devs/LTR/modules/LTRModuleRawWordsTracker.cpp
        ${LQMEAS_DIR}/devs/LTR/marks/LTRSyncMarks.h
        ${LQMEAS_DIR}/devs/LTR/marks/LTRSyncMarks.cpp
        ${LQMEAS_DIR}/devs/LTR/marks/LTRSyncMarksRecvConfig.h
        ${LQMEAS_DIR}/devs/LTR/marks/LTRSyncMarksRecvConfig.cpp
        ${LQMEAS_DIR}/devs/LTR/marks/LTRSyncMarksRecvInfo.h
        ${LQMEAS_DIR}/devs/LTR/marks/LTRSyncMarksRecvInfo.cpp
    )
endif(LQMEAS_DEV_LTR)


list(FIND LQMEAS_DEVS LPW25 LPW25_IDX)
if(NOT LPW25_IDX EQUAL -1)
    set(LQMEAS_DEV_LPW25 ON)
    set(LQMEAS_USE_TEDS ON)
    set(LQMEAS_LTRAPI_COMPONENTS ${LQMEAS_LTRAPI_COMPONENTS} lpw25api)

    set(LQMEAS_SOURCES ${LQMEAS_SOURCES}
        ${LQMEAS_DIR}/sensors/LPW25/LPW25.h
        ${LQMEAS_DIR}/sensors/LPW25/LPW25.cpp
        ${LQMEAS_DIR}/sensors/LPW25/LPW25TypeInfo.h
        ${LQMEAS_DIR}/sensors/LPW25/LPW25TypeInfo.cpp
        ${LQMEAS_DIR}/sensors/LPW25/LPW25Info.h
        ${LQMEAS_DIR}/sensors/LPW25/LPW25Info.cpp
        ${LQMEAS_DIR}/sensors/LPW25/LPW25SensorROutUpdater.h
        ${LQMEAS_DIR}/sensors/LPW25/LPW25SensorROutUpdater.cpp
        )

endif(NOT LPW25_IDX EQUAL -1)


if(LQMEAS_USE_TEDS)
    set(LQMEAS_SOURCES ${LQMEAS_SOURCES}
        ${LQMEAS_DIR}/ifaces/teds/DevTedsAccess.h
        ${LQMEAS_DIR}/ifaces/teds/DevTedsAccess.cpp
        ${LQMEAS_DIR}/ifaces/teds/TedsDataRdStream.h
        ${LQMEAS_DIR}/ifaces/teds/TedsDataRdStream.cpp
        ${LQMEAS_DIR}/ifaces/teds/TedsTransducer.h
        ${LQMEAS_DIR}/ifaces/teds/TedsTransducer.cpp
        ${LQMEAS_DIR}/ifaces/teds/info/TedsInfo.h
        ${LQMEAS_DIR}/ifaces/teds/info/TedsInfo.cpp
        ${LQMEAS_DIR}/ifaces/teds/info/TedsBasicInfo.h
        ${LQMEAS_DIR}/ifaces/teds/info/TedsBasicInfo.cpp
        )

    set(LQMEAS_LTRAPI_COMPONENTS ${LQMEAS_LTRAPI_COMPONENTS} ltedsapi)
endif(LQMEAS_USE_TEDS)

if(LQMEAS_DEV_LTR01)
    set(LQMEAS_SOURCES ${LQMEAS_SOURCES}
        ${LQMEAS_DIR}/devs/LTR/modules/LTR01.h
        ${LQMEAS_DIR}/devs/LTR/modules/LTR01.cpp
        )

    set(LQMEAS_LTRAPI_COMPONENTS ${LQMEAS_LTRAPI_COMPONENTS} ltr01api)
endif(LQMEAS_DEV_LTR01)


#так как некоторые компоненты ltrapi могут избользоваться вне LTR,
#то проверку компонентов и подключение нужных библиотек делаем
#отдельно от проверки условиня LQMEAS_DEV_LTR
if(LQMEAS_LTRAPI_COMPONENTS)
    find_package(LTRAPI REQUIRED ${LQMEAS_LTRAPI_COMPONENTS})

    set(LQMEAS_INCLUDE_DIRS ${LQMEAS_INCLUDE_DIRS} ${LTRAPI_INCLUDE_DIRS})
    set(LQMEAS_COMPILE_DEFINITIONS ${LQMEAS_COMPILE_DEFINITIONS} ${LTRAPI_COMPILE_DEFINITIONS})
    set(LQMEAS_LIBRARIES ${LQMEAS_LIBRARIES} ${LTRAPI_LIBRARIES})
endif(LQMEAS_LTRAPI_COMPONENTS)



set(LCOMP_DEVICES E2010 E14_440 E14_140)

foreach(LCOMP_DEVICE ${LCOMP_DEVICES})
    list(FIND LQMEAS_DEVS ${LCOMP_DEVICE} ${LCOMP_DEVICE}_IDX)
    if(NOT ${LCOMP_DEVICE}_IDX EQUAL -1)
        string(TOLOWER ${LCOMP_DEVICE} LCOMP_MODULE_LOWER)

        set(LQMEAS_DEV_${LCOMP_DEVICE}  ON)
        set(LQMEAS_DEV_LCOMP            ON)
        set(LQMEAS_DEV_DIR ${LQMEAS_DIR}/devs/lcomp/modules/${LCOMP_DEVICE})

        set(LQMEAS_SOURCES ${LQMEAS_SOURCES}
            ${LQMEAS_DEV_DIR}/${LCOMP_DEVICE}.h
            ${LQMEAS_DEV_DIR}/${LCOMP_DEVICE}.cpp
            ${LQMEAS_DEV_DIR}/${LCOMP_DEVICE}Config.h
            ${LQMEAS_DEV_DIR}/${LCOMP_DEVICE}Config.cpp
            ${LQMEAS_DEV_DIR}/${LCOMP_DEVICE}Info.h
            ${LQMEAS_DEV_DIR}/${LCOMP_DEVICE}TypeInfo.h
            ${LQMEAS_DEV_DIR}/${LCOMP_DEVICE}TypeInfo.cpp
         )
    endif()
endforeach()

if(LQMEAS_DEV_LCOMP)

    if(WIN32 AND NOT LCOMP_LIBRARY_ROOT_DIR)
        set(LCOMP_LIBRARY_ROOT_DIR "c:/Program Files (x86)/L-Card/LIBRARY")
    endif()
    set(LQMEAS_INCLUDE_DIRS ${LQMEAS_INCLUDE_DIRS} ${LCOMP_LIBRARY_ROOT_DIR})

    set(LQMEAS_SOURCES ${LQMEAS_SOURCES}
        ${LQMEAS_DIR}/devs/lcomp/lcomp_headers.h
        ${LQMEAS_DIR}/devs/lcomp/lcompErrors.h
        ${LQMEAS_DIR}/devs/lcomp/lcompResolver.h
        ${LQMEAS_DIR}/devs/lcomp/lcompResolver.cpp
        ${LQMEAS_DIR}/devs/lcomp/lcompDevice.h
        ${LQMEAS_DIR}/devs/lcomp/lcompDevice.cpp
        ${LQMEAS_DIR}/devs/lcomp/lcompStreamDevice.h
        ${LQMEAS_DIR}/devs/lcomp/lcompStreamDevice.cpp
        ${LQMEAS_DIR}/devs/lcomp/lcompStreamReceiver.h
        ${LQMEAS_DIR}/devs/lcomp/lcompStreamReceiver.cpp
        ${LQMEAS_DIR}/devs/lcomp/lcompRecvProcessorIface.h
        ${LQMEAS_DIR}/devs/lcomp/lcompSeqAdcConfig.cpp
        ${LQMEAS_DIR}/devs/lcomp/lcompSeqAdcConfig.h
    )
endif(LQMEAS_DEV_LCOMP)



set(X502_DEVICES E502 L502)
foreach(X502_DEVICE ${X502_DEVICES})    
    list(FIND LQMEAS_DEVS ${X502_DEVICE} ${X502_DEVICE}_IDX)
    if(NOT ${X502_DEVICE}_IDX EQUAL -1)
        string(TOLOWER ${X502_DEVICE}  X502_DEVICE_LOWER)
        set(LQMEAS_DEV_${X502_DEVICE}  ON)
        set(LQMEAS_DEV_X502            ON)
        set(X502API_COMPONENTS         ${X502API_COMPONENTS} ${X502_DEVICE_LOWER}api)

        set(LQMEAS_DEV_DIR ${LQMEAS_DIR}/devs/x502/modules/${X502_DEVICE})

        set(LQMEAS_SOURCES ${LQMEAS_SOURCES}
            ${LQMEAS_DEV_DIR}/${X502_DEVICE}.h
            ${LQMEAS_DEV_DIR}/${X502_DEVICE}.cpp
            ${LQMEAS_DEV_DIR}/${X502_DEVICE}Info.h
            ${LQMEAS_DEV_DIR}/${X502_DEVICE}TypeInfo.h
            ${LQMEAS_DEV_DIR}/${X502_DEVICE}TypeInfo.cpp
        )

        if (${X502_DEVICE} STREQUAL E502)
            set(LQMEAS_SOURCES ${LQMEAS_SOURCES}
                ${LQMEAS_DIR}/devs/x502/modules/E502/E502DeviceRefIPAddr.h
                ${LQMEAS_DIR}/devs/x502/modules/E502/E502DeviceRefIPAddr.cpp
                )
        endif(${X502_DEVICE} STREQUAL E502)
    endif()
endforeach()


if(LQMEAS_DEV_X502)
    find_package(X502API REQUIRED ${X502API_COMPONENTS})

    set(LQMEAS_INCLUDE_DIRS ${LQMEAS_INCLUDE_DIRS} ${X502API_INCLUDE_DIRS})
    set(LQMEAS_LIBRARIES ${LQMEAS_LIBRARIES} ${X502API_LIBRARIES})

    set(LQMEAS_SOURCES ${LQMEAS_SOURCES}
        ${LQMEAS_DIR}/devs/x502/x502NativeError.h
        ${LQMEAS_DIR}/devs/x502/x502NativeError.cpp
        ${LQMEAS_DIR}/devs/x502/x502.h
        ${LQMEAS_DIR}/devs/x502/x502.cpp
        ${LQMEAS_DIR}/devs/x502/x502TypeInfo.h
        ${LQMEAS_DIR}/devs/x502/x502TypeInfo.cpp
        ${LQMEAS_DIR}/devs/x502/x502Info.h
        ${LQMEAS_DIR}/devs/x502/x502Info.cpp
        ${LQMEAS_DIR}/devs/x502/x502Config.h
        ${LQMEAS_DIR}/devs/x502/x502Config.cpp
        ${LQMEAS_DIR}/devs/x502/x502AdcConfig.h
        ${LQMEAS_DIR}/devs/x502/x502AdcConfig.cpp
        ${LQMEAS_DIR}/devs/x502/x502OutConfig.h
        ${LQMEAS_DIR}/devs/x502/x502OutConfig.cpp
        ${LQMEAS_DIR}/devs/x502/x502Resolver.h
        ${LQMEAS_DIR}/devs/x502/x502Resolver.cpp
    )


    set(LQMEAS_SOURCES ${LQMEAS_SOURCES}
        ${LQMEAS_DIR}/devs/x502/modules/E502/netBrowser/E502DeviceRefNetSvc.h
        ${LQMEAS_DIR}/devs/x502/modules/E502/netBrowser/E502DeviceRefNetSvc.cpp
        ${LQMEAS_DIR}/devs/x502/modules/E502/netBrowser/E502NetSvcRecord.h
        ${LQMEAS_DIR}/devs/x502/modules/E502/netBrowser/E502NetSvcRecord.cpp
        ${LQMEAS_DIR}/devs/x502/modules/E502/netBrowser/E502NetworkBrowser.h
        ${LQMEAS_DIR}/devs/x502/modules/E502/netBrowser/E502NetworkBrowser.cpp
        )
endif(LQMEAS_DEV_X502)



list(FIND LQMEAS_DEVS Agilent3458 Agilent3458_IDX)
if(NOT Agilent3458_IDX EQUAL -1)
    set(LQMEAS_DEV_AGILENT_3458  ON)

    set(LQMEAS_INCLUDE_DIRS ${LQMEAS_INCLUDE_DIRS} ${AG3458API_INCLUDE_DIR})
    set(LQMEAS_LIBRARY_DIRS ${LQMEAS_LIBRARY_DIRS} ${AG3458API_LIBRARIES_DIR})

    set(LQMEAS_LIBRARIES ${LQMEAS_LIBRARIES} Agilent3458api)

    set(LQMEAS_SOURCES ${LQMEAS_SOURCES}
        ${LQMEAS_DIR}/devs/gpib/gpibResolver.h
        ${LQMEAS_DIR}/devs/gpib/gpibResolver.cpp
        ${LQMEAS_DIR}/devs/gpib/Agilent3458.h
        ${LQMEAS_DIR}/devs/gpib/Agilent3458.cpp
    )
endif()

configure_file(${LQMEAS_DIR}/lqmeas_config.h.in ${CMAKE_CURRENT_BINARY_DIR}/lqmeas_config.h)
set(LQMEAS_INCLUDE_DIRS ${LQMEAS_INCLUDE_DIRS} ${CMAKE_CURRENT_BINARY_DIR})


include(${LQMEAS_DIR}/translations/cmake/qtranslation.cmake)

set(LQMEAS_TS_BASENAME lqmeas)
qtranslation_generate(LQMEAS_TRANSLATION_FILES ${LQMEAS_DIR}/translations ${LQMEAS_TS_BASENAME} ${LQMEAS_SOURCES})
set(LQMEAS_GENFILES ${LQMEAS_GENFILES}  ${LQMEAS_TRANSLATION_FILES})

set(LQMEAS_FILES  ${LQMEAS_SOURCES} ${LQMEAS_GENFILES})


